@@ -3,7 +3,7 @@
  *
  * "Chromium B.S.U." is free software; you can redistribute 
  * it and/or use it and/or modify it under the terms of the 
- * "Artistic License" 
+ * "Clarified Artistic License"
  */
 
 #ifdef HAVE_CONFIG_H
@@ -186,6 +186,8 @@ AudioOpenAL::~AudioOpenAL()
 		alDeleteSources(NumSoundTypes, source);
 		alDeleteBuffers(NumSoundTypes, buffer);
 
+		alcMakeContextCurrent(NULL);
+
 		#ifdef _WIN32
 		if(context_id)
 			alcDestroyContext((ALCcontext*)context_id);
@@ -908,7 +910,7 @@ bool AudioOpenAL::loadWAV(const char *filename)
 	return false;
 #else //USE_PLAYLIST
 #if defined(ALUT_API_MAJOR_VERSION) && ALUT_API_MAJOR_VERSION >= 1
-	buffer[MusicGame] = alutCreateBufferFromFile(const_cast<ALbyte*>(filename));
+	buffer[MusicGame] = alutCreateBufferFromFile(filename);
 	if( buffer[MusicGame] == AL_NONE ) checkError();
 	return buffer[MusicGame] != AL_NONE;
 #else
