@@ -3,7 +3,7 @@
  *
  * "Chromium B.S.U." is free software; you can redistribute 
  * it and/or use it and/or modify it under the terms of the 
- * "Artistic License" 
+ * "Clarified Artistic License"
  */
 #ifndef MainSDL_h
 #define MainSDL_h
@@ -25,7 +25,7 @@ public:
 	bool run();
 	bool checkErrors();
 	
-	void setVideoMode();
+	bool setVideoMode();
 	
 	void grabMouse(bool,bool=true);
 
