@@ -3,7 +3,7 @@
  *
  * "Chromium B.S.U." is free software; you can redistribute 
  * it and/or use it and/or modify it under the terms of the 
- * "Artistic License" 
+ * "Clarified Artistic License"
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,6 +41,11 @@ ScreenItemAdd::ScreenItemAdd()
 ScreenItemAdd::~ScreenItemAdd()
 {
 	clear();
+	for(int i = 0; i < NumEnemyTypes; i++)
+	{
+		delete deadPool[i];
+		deadPool[i] = NULL;
+	}
 	delete root;
 }
 
